/*
  Sort all the points around o lexicographically by polar angle and
  distance from o
*/

#include <algorithm> // std::sort
#include <cstddef> // std::size_t
#include <iterator> // std::iterator_traits

#define MULTI_PRECISION

#include "point.h++"

namespace angular_sort {

  template<typename I>
  I solve(I first, I past) {
    using P = typename std::iterator_traits<I>::value_type;
    I west = std::min_element(first, past,
      [](P const& p, P const& q) -> bool {
        return (p.x < q.x) or (p.x == q.x and p.y < q.y);
      });
    P o = *west;
    std::sort(first, past,
      [&](P const& p, P const& q) -> bool {
        int turn = orientation(o, p, q);
        if (turn == 0) {
          return (L_infty_distance(o, p) < L_infty_distance(o, q));
        }
        return (turn == +1);
      });
    return past;
  }
}