report-directory=$(CPHSTL)/Report
language=british

latex-file:= supplement.tex
latex-base:= $(basename $(latex-file))
pdf-file:= $(addsuffix .pdf, $(latex-base))
dictionary-file:= $(addsuffix .dict, $(latex-base))

where-am-i = $(CURDIR)/$(word $(words $(MAKEFILE_LIST)),$(MAKEFILE_LIST))
this-makefile = $(call where-am-i)

.PHONY: clean copy default find package spell veryclean

default: $(pdf-file)

copy:
	cp $(report-directory)/DIKU-report.cls .
	cp $(report-directory)/DIKU.bst .
	cp $(report-directory)/hyphenation.txt .
	cp $(report-directory)/listings-setup.tex .
	cp $(report-directory)/shortstrings.bib .

$(pdf-file): %.pdf: %.tex
	pdflatex $*.tex
	bibtex $*
	pdflatex $*.tex
	pdflatex $*.tex
	@detex $*.tex | ispell -d $(language) -p $*.dict -t -l | grep "" && echo "Above words were not in the dictionary." || true
	make -f $(this-makefile) -s clean

spell: $(latex-base)

$(latex-base): %: %.tex
	detex $*.tex | ispell -w "ÅåØøÆÆ_" -d $(language) -p $*.dict -t -l | grep "" || true

date=`date +%Y-%m-%d`

package:
	chmod u+rw *
	zip supplement-$(date).zip supplement.pdf supplement.tex supplement.bib hyphenation.txt listings-setup.tex shortstrings.bib DIKU-report.cls DIKU.bst report.mk copyright release-notes use-case.c++ plane_sweep.h++ torch.h++ quickhull.h++ poles_first.h++ throw_away.h++ introhull.h++ sort.h++ lexicographic_sort.h++ angular_sort.h++ point.h++ validation.h++ check-driver.c++ test-driver.c++ driver.c++ makefile

find :
	find . -type f -print -exec grep $(word) {} \; | less #

clean :
	-rm -f core *.out *.bak supplement.log *.aux *.bbl *.blg *.toc *~ .nfs* || true

veryclean : clean
	rm -f supplement.pdf || true
